Python client for Jiggy open source components

pip install jiggy

set api key via environment variable: "JIGGY_API_KEY"

This is in an experimental form and not suitable for large vector collections or production use cases.
